#include "support.h"

#include <QTimer>
#include <QGuiApplication>
#include <QQmlContext>
#include <private/qquickpathview_p.h>

Support::Support(QQmlApplicationEngine* engine, QObject *parent)
    : QThread(parent)
    , state(false)
    , m_engine(engine)
{
    connect(this, SIGNAL(finished()), this, SLOT(deleteLater()));
    start();
}

Support::~Support()
{
    quit();
    wait();
}

void Support::run()
{
    QTimer timer;
    connect(&timer, SIGNAL(timeout()), this, SLOT(wakeup()));

    timer.setInterval(5000);
    timer.start();
    exec();
    timer.stop();
}

void Support::wakeup()
{
    state = !state;
    emit stateChanged(state);
    QObject* rootObject = m_engine->rootObjects().first();
    QObject* qmlObject = rootObject->findChild<QObject*>("pathView");
    QQuickPathView* pathView = qobject_cast<QQuickPathView*>(qmlObject);

    pathView->setInteractive(!state);
    pathView->setEnabled(!state);
    pathView->ungrabMouse();
}
